==> helm_2.7.1.orig.tar.xz: helm-2.7.1/README.md <==
<p align="center"><a href="http://www.gnu.org/licenses/gpl-3.0.txt"><img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" /></a>
  <a href="https://melpa.org/#/helm"><img alt="MELPA" src="https://melpa.org/packages/helm-badge.svg"/></a>
  <a href="https://stable.melpa.org/#/helm"><img alt="MELPA Stable" src="https://stable.melpa.org/packages/helm-badge.svg"/></a>
</p>


<h1 align="center">Emacs-helm</h1>

<p align="center">
  <img src="https://avatars3.githubusercontent.com/u/1541688?v=3&amp;s=200" alt="Emacs-helm" title="" />
</p>

***
<p align="justify">
  <b>Helm</b> is an Emacs framework for incremental completions and narrowing
  selections. It helps to rapidly complete file names, buffer names, or
  any other Emacs interactions requiring selecting an item from a list of
  possible choices.
  Helm is a fork of <b>anything.el</b>, which was originally written by Tamas
  Patrovic and can be considered to be its successor. <b>Helm</b> cleans the
  legacy code that is leaner, modular, and unchained from constraints of
  backward compatibility.
</p>

***
<p align="center">
  <a href="https://emacs-helm.github.io/helm/"><b>Homepage</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki#install"><b>Get started</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki"><b>Helm wiki</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki/FAQ"><b>FAQ</b></a>
</p>

***

<p align="center">
  Maintainance of Helm is a <a href="https://github.com/emacs-helm/helm/commits?author=thierryvolpiatto"><b>Lot of work</b></a>
  I have done freely since 2011.<br>
  As it is taking a lot of my time it starts to be more and more difficult<br>
  maintaining it without financial help.<br>
  If you feel Helm is making your daily work easier,<br><b>please consider making a donation.</b>
</p>

<p align="center">
  <i>Thank you! &mdash; Thierry Volpiatto</i>
</p>

<div align="center">
  <a href="https://www.paypal.me/thierryvolpiatto/20">
    <img title="Donate with Paypal"
         alt="Donate with Paypal"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/paypal.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://patreon.com/preview/30231724baf440fabe80d44d0ee77067">
    <img title="Donate monthly using Patreon"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/patreon-25x.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://gratipay.com/emacs-helm/">
    <img title="Donate weekly using Gratipay"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://cdn.rawgit.com/gratipay/gratipay-badge/2.3.0/dist/gratipay.png"></a>
</div>

***

<p align="center">
  Helm in action searching with <a href="https://github.com/ggreer/the_silver_searcher"<b>Grep Ag</b></a>
                                   </p>

<p align="center">
  <img src="https://github.com/emacs-helm/helm/blob/master/images/helm-grep-ag-persistent.png?raw=true" alt="Emacs-helm grep ag" title="" />
</p>

[badge-license]: https://img.shields.io/badge/license-GPL_3-green.svg

==> helm_2.8.2.orig.tar.xz: helm-2.8.2/README.md <==
<p align="center"><a href="http://www.gnu.org/licenses/gpl-3.0.txt"><img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" /></a>
  <a href="https://melpa.org/#/helm"><img alt="MELPA" src="https://melpa.org/packages/helm-badge.svg"/></a>
  <a href="https://stable.melpa.org/#/helm"><img alt="MELPA Stable" src="https://stable.melpa.org/packages/helm-badge.svg"/></a>
</p>


<h1 align="center">Emacs-helm</h1>

<p align="center">
  <img src="https://avatars3.githubusercontent.com/u/1541688?v=3&amp;s=200" alt="Emacs-helm" title="" />
</p>

***
<p align="justify">
  <b>Helm</b> is an Emacs framework for incremental completions and narrowing
  selections. It provides an easy to use API for developers wanting to build 
  their own helm applications in Emacs and dozens of already build in commands
  providing completion in almost everything and powerful search tools.
  It is a must have for anyone wanting to use Emacs as its main working environment.
  Helm is now popular and have been adopted by many power Emacs users.
  It is available in Melpa for easy installation from the Emacs package manager.
</p>

***
<p align="center">
  <a href="https://emacs-helm.github.io/helm/"><b>Homepage</b></a> |
  <a href="https://github.com/emacs-helm/helm/releases"><b>Downloads</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki#install"><b>Get started</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki"><b>Helm wiki</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki/FAQ"><b>FAQ</b></a>
</p>

***

<p align="center">
  Maintainance of Helm is a <a href="https://github.com/emacs-helm/helm/commits?author=thierryvolpiatto"><b>Lot of work</b></a>
  I have done freely since 2011.<br>
  As it is taking a lot of my time it starts to be more and more difficult<br>
  maintaining it without financial help.<br>
  If you feel Helm is making your daily work easier,<br><b>please consider making a donation.</b>
</p>

<p align="center">
  <i>Thank you! &mdash; Thierry Volpiatto</i>
</p>

<div align="center">
  <a href="https://www.paypal.me/thierryvolpiatto/20">
    <img title="Donate with Paypal"
         alt="Donate with Paypal"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/paypal.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://patreon.com/preview/30231724baf440fabe80d44d0ee77067">
    <img title="Donate monthly using Patreon"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/patreon-25x.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://gratipay.com/emacs-helm/">
    <img title="Donate weekly using Gratipay"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://cdn.rawgit.com/gratipay/gratipay-badge/2.3.0/dist/gratipay.png"></a>
</div>

***

<p align="center">
  Helm in action searching with <a href="https://github.com/ggreer/the_silver_searcher"<b>Grep Ag</b></a>
                                   </p>

<p align="center">
  <img src="https://github.com/emacs-helm/helm/blob/master/images/helm-grep-ag-persistent.png?raw=true" alt="Emacs-helm grep ag" title="" />
</p>

[badge-license]: https://img.shields.io/badge/license-GPL_3-green.svg
